aboutsummaryrefslogtreecommitdiff
path: root/bbot/worker/worker.cxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2024-11-18 17:09:26 +0200
committerKaren Arutyunov <karen@codesynthesis.com>2024-11-18 17:09:26 +0200
commita27a01a76740a5ba9b236eb20ccfa5c404020018 (patch)
tree5756e7db341d056cf114d2ca9451b3dd168f61ae /bbot/worker/worker.cxx
parent58fd548d4e2227a61cc840e5fc9ea435d57ed4f9 (diff)
Allow disabling b.test-installed.create and bpkg.test-separate-installed.create steps in worker
Diffstat (limited to 'bbot/worker/worker.cxx')
-rw-r--r--bbot/worker/worker.cxx14
1 files changed, 10 insertions, 4 deletions
diff --git a/bbot/worker/worker.cxx b/bbot/worker/worker.cxx
index 051cc15..d413912 100644
--- a/bbot/worker/worker.cxx
+++ b/bbot/worker/worker.cxx
@@ -1547,7 +1547,9 @@ build (size_t argc, const char* argv[])
prefix != "bpkg.bindist.archive" &&
prefix != "bbot.sys-install" &&
prefix != "bbot.sys-install.ldconfig" &&
+ prefix != "b.test-installed.create" &&
prefix != "b.test-installed.test" &&
+ prefix != "bpkg.test-separate-installed.create" &&
prefix != "bpkg.test-separate-installed.update" &&
prefix != "bpkg.test-separate-installed.test" &&
prefix != "bbot.bindist.upload" &&
@@ -5021,7 +5023,8 @@ build (size_t argc, const char* argv[])
// Run internal tests.
//
- if (has_internal_tests)
+ if (has_internal_tests &&
+ !step_disabled (step_id::b_test_installed_create))
{
// Create the configuration.
//
@@ -5165,7 +5168,8 @@ build (size_t argc, const char* argv[])
}
//
// Fail if the breakpoint refers to some of the b.test-installed.*
// steps but the package doesn't have any internal tests.
//
else if (bkp_step &&
*bkp_step >= step_id::b_test_installed_create &&
@@ -5180,7 +5184,8 @@ build (size_t argc, const char* argv[])
// Note that we only build runtime tests for target packages and for
// host packages in self-hosted configurations.
//
- if (has_runtime_tests || has_buildtime_tests)
+ if ((has_runtime_tests || has_buildtime_tests) &&
+ !step_disabled (step_id::bpkg_test_separate_installed_create))
{
// Stash the absolute path of the initial build target
// configuration.
@@ -5863,7 +5868,8 @@ build (size_t argc, const char* argv[])
//
// Fail if the breakpoint refers to some of the
// bpkg.test-separate-installed.* steps but the package has no
- // external tests.
+ // external tests or the bpkg.test-separate-installed.create step is
+ // disabled.
//
else if (bkp_step &&
*bkp_step >= step_id::bpkg_test_separate_installed_create &&
@@ -5165,7 +5168,8 @@ build (size_t argc, const char* argv[])
//
// Fail if the breakpoint refers to some of the b.test-installed.*
- // steps but the package doesn't have any internal tests.
+ // steps but the package doesn't have any internal tests or the
+ // b.test-installed.create step is disabled.
//
else if (bkp_step &&